# vtspy: VERITAS analysis package 

vtspy allows to analyze the VERITAS DL3 data and analyze the joint VERITAS and Fermi-LAT analysis with gammapy and fermipy.
For full documentation visit: https://vtspy.readthedocs.io/en/latest/index.html

## Install

### Users
``` 
pip install vtspy
```

### Developers

``` 
git clone https://github.com/takdg123/vtspy.git
cd vtspy 
pip install .
```

## Main contributors

Donggeun Tak (DESY), 	
Pedro Ivo Silva Batista (DESY),
Arkadipta Sarkar (DESY)
